@@ -1237,11 +1237,13 @@ pong_runtime_element_set_value (PongRuntimeElement *gre, GConfValue *value)
 	g_return_if_fail (value != NULL);
 
 	old_value = pong_runtime_element_get_value (gre);
-	if (pong_gconf_value_equal (value, old_value)) {
+	if (old_value != NULL &&
+	    pong_gconf_value_equal (value, old_value)) {
 		gconf_value_free (old_value);
 		return;
 	}
-	gconf_value_free (old_value);
+	if (old_value != NULL)
+		gconf_value_free (old_value);
 
 	if (gre->widget_type == PONG_NATIVEWIDGET) {
 		if ( ! pong_widget_interface_set_value (gre->widget,
