@@ -114,36 +114,48 @@ type_hash_init (void)
 	}
 }
 
-static void
-type_from_string (const char *string, PongType *type, GtkType *gtk_type)
+void
+pong_pane_type_from_string (const char *string,
+			    PongType *type,
+			    GtkType *gtk_type)
 {
 	char *typestring;
 	char *initfunc;
 	guint (*get_type)(void);
 	gpointer klass;
+	GtkType lgtk_type;
 
-	*gtk_type = *type = 0;
+	g_return_if_fail (string != NULL);
+
+	if (type != NULL)
+		*type = 0;
+	if (gtk_type != NULL)
+		*gtk_type = 0;
 
 	/* make sure we have the native widget classes in gtk type table */
 	pong_lazy_init ();
 
-	if( ! type_hash)
-		type_hash_init ();
-
 	typestring = remove_sep (string);
-	/* this will give 0, which is the invalid widget, if we don't
-	 * find the string */
-	*type = GPOINTER_TO_INT (g_hash_table_lookup (type_hash, typestring));
-	if (*type > 0) {
-		g_free (typestring);
-		return;
+
+	if (type != NULL) {
+		if( ! type_hash)
+			type_hash_init ();
+
+		/* this will give 0, which is the invalid widget, if we don't
+		 * find the string */
+		*type = GPOINTER_TO_INT (g_hash_table_lookup (type_hash,
+							      typestring));
+		if (*type > 0) {
+			g_free (typestring);
+			return;
+		}
 	}
 
-	*gtk_type = gtk_type_from_name (typestring);
+	lgtk_type = gtk_type_from_name (typestring);
 
 	g_free (typestring);
 
-	if (*gtk_type == 0) {
+	if (lgtk_type == 0) {
 		if( ! g_module_supported ()) {
 			g_warning (_("GModule is not supported and a widget "
 				     "of type '%s' has not yet been "
@@ -168,35 +180,39 @@ type_from_string (const char *string, PongType *type, GtkType *gtk_type)
 
 		g_assert(get_type != NULL);
 
-		*gtk_type = get_type();
+		lgtk_type = get_type();
 	}
 
-	if(*gtk_type == 0) {
-		g_warning(_("Unknown widget '%s' found"), string);
+	if (lgtk_type == 0) {
+		g_warning (_("Unknown widget '%s' found"), string);
 		return;
 	}
 
 	/* we use gtk_type_name as a checking thing to see if this type
 	 * actually exists */
-	if( ! gtk_type_name(*gtk_type)) {
-		g_warning(_("Strange widget type '%s' found"), string);
-		*gtk_type = 0;
+	if( ! gtk_type_name (lgtk_type)) {
+		g_warning (_("Strange widget type '%s' found"), string);
 		return;
 	}
 	
-	if( ! gtk_type_is_a(*gtk_type, gtk_widget_get_type())) {
-		g_warning(_("Non-widget object '%s' found"), string);
-		*gtk_type = 0;
+	if( ! gtk_type_is_a (lgtk_type, gtk_widget_get_type())) {
+		g_warning (_("Non-widget object '%s' found"), string);
 		return;
 	}
 
-	klass = gtk_type_class(*gtk_type);
-	
-	if (g_dataset_get_data (klass, "pong_widget_interface") != NULL) {
-		*type = PONG_NATIVEWIDGET;
-	} else {
-		*type = PONG_EXTRAWIDGET;
+	if (type != NULL) {
+		klass = gtk_type_class(lgtk_type);
+
+		if (g_dataset_get_data (klass,
+					"pong_widget_interface") != NULL) {
+			*type = PONG_NATIVEWIDGET;
+		} else {
+			*type = PONG_EXTRAWIDGET;
+		}
 	}
+
+	if (gtk_type != NULL)
+		*gtk_type = lgtk_type;
 }
 
 /*
@@ -647,7 +663,7 @@ pong_widget_set_widget_type_string (PongWidget *widget, const char *widget_type)
 	g_return_if_fail (widget->base.type == PONG_WIDGET);
 	g_return_if_fail (widget_type != NULL);
 
-	type_from_string (widget_type, &type, &gtk_type);
+	pong_pane_type_from_string (widget_type, &type, &gtk_type);
 
 	pong_widget_set_widget_type (widget, type);
 	pong_widget_set_widget_gtktype (widget, gtk_type);
@@ -954,6 +970,7 @@ pong_dialog_setup_tooltip (PongDialog *dialog, GtkWidget *widget, const char *to
 	return w;
 }
 
+
 static GtkWidget *
 pong_dialog_make_widget (PongDialog *dialog, PongWidget *widget,
 			 GtkWidget **labelw)
@@ -1021,6 +1038,9 @@ pong_dialog_make_widget (PongDialog *dialog, PongWidget *widget,
 
 	case PONG_GTKSPINBUTTON:
 		realwid = w = gtk_spin_button_new (NULL, 1, 0);
+		gtk_signal_connect (GTK_OBJECT (w), "map",
+				    GTK_SIGNAL_FUNC (pong_spin_button_mapped),
+				    NULL);
 		pong_gtk_widget_set_arguments (realwid, widget->arguments);
 		gtk_widget_show (w);
 		if (widget->base.label != NULL)
@@ -1509,7 +1529,8 @@ dialog_setup_unknowns (PongElement *element, gpointer data)
 			widget->widget_type = PONG_GTKCHECKBUTTON;
 			break;
 		case PONG_TYPE_INT:
-			widget->widget_type = PONG_GTKSPINBUTTON;
+			widget->widget_type = PONG_NATIVEWIDGET;
+			widget->widget_gtktype = pong_spin_button_get_type ();
 			break;
 		case PONG_TYPE_FLOAT:
 			widget->widget_type = PONG_GNOMENUMBERENTRY;
