@@ -2,6 +2,7 @@
  * Author: George Lebl
  * (c) 1999 Free Software Foundation
  * (c) 2000 Eazel, Inc.
+ * (c) 2001 George Lebl
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -1602,7 +1603,7 @@ pong_parser_free_unused_data (void)
 }
 
 static void
-add_elements_to_list (gpointer key, gpointer data, gpointer user_data)
+add_element_keys_to_list (gpointer key, gpointer data, gpointer user_data)
 {
 	GList **list = user_data;
 	*list = g_list_prepend (*list, key);
@@ -1615,6 +1616,25 @@ pong_file_get_conf_paths (const PongFile *gf)
 	GList *list = NULL;
 	g_return_val_if_fail (gf != NULL, NULL);
 
+	g_hash_table_foreach (gf->element_hash, add_element_keys_to_list,
+			      &list);
+
+	return list;
+}
+
+static void
+add_elements_to_list (gpointer key, gpointer data, gpointer user_data)
+{
+	GList **list = user_data;
+	*list = g_list_prepend (*list, data);
+}
+
+GList *
+pong_file_get_elements (const PongFile *gf)
+{
+	GList *list = NULL;
+	g_return_val_if_fail (gf != NULL, NULL);
+
 	g_hash_table_foreach (gf->element_hash, add_elements_to_list, &list);
 
 	return list;
